**Example 1: 创建域名解析记录**



Input: 

```
tccli gaap CreateGlobalDomainDns --cli-unfold-argument  \
    --ProxyIdList 111 \
    --NationCountryInnerCodes 221 \
    --DomainId test.com
```

Output: 
```
{
    "Response": {
        "RequestId": "19a021f8-dff3-4890-8e7a-ed5054e22e49"
    }
}
```

